@@ -46,7 +46,8 @@ def resample(
     global_storage = "root://eoslhcb.cern.ch//eos/lhcb/wg/PID/PIDGen2/templates/", 
     cachedir = None, 
     eta_from_p = False, 
-    nan = -1000.
+    nan = -1000., 
+    scale = None
   ) : 
 
   input_branches = branches.split(":")
@@ -143,7 +144,7 @@ def resample(
 
       onp.random.seed(resampling_seed)
 
-      data = data_transform(input_data, config)
+      data = data_transform(input_data, config, scale = [ float(i) for i in scale.split(":")] if scale else None )
       pid_arr, calib_stat = resample_data(data, config, vardef, template, verbose = verbose)
 
       if not (nan is None) : 
@@ -222,6 +223,8 @@ def main() :
                       help='Calculate eta from p and pT branches')
   parser.add_argument('--nan', type=float, default = -1000., 
                       help="Numerical value to replace NaN in resampled PID (when calibration data is missing)")
+  parser.add_argument('--scale', type=str, default = None, 
+                      help="List of scale factors for input data e.g. '1:1:1.15' for 15%% upscaling of multiplicity")
 
   args = parser.parse_args()
 
