@@ -109,6 +109,11 @@ def read_calib_tuple(sample, trees, branches, verbose = False, cachedir = None,
       except FileNotFoundError : 
         print(f"... file not found, skipping")
         break
+
+      except OSError : 
+        print(f"... XRootD error reading calibration file {filename}. Please check your Kerberos ticket and try again. ")
+        raise SystemExit
+
     if cachedir : 
       file.close()
 
@@ -188,34 +193,27 @@ def calib_transform(x, config, variable) :
     arr += [ t(xs) ]
   arr += [ x[:,-1] ] # sWeight
 
-#  arr = [ 
-#
-#    transform_sample[0](x[:,1]),  # pT
-#    transform_sample[1](x[:,2]),  # eta
-#    transform_sample[2](x[:,3] + onp.random.uniform(size = x.shape[0]) - 0.5 ),   # Ntracks (add uniform random +-0.5)
-#    x[:,4]  # sWeight
-#  ]
   return np.stack(arr, axis = 1)
 
-def data_transform(x, config) :
+def data_transform(x, config, scale = None) :
   """
   Apply variable transformation to the data array. 
 
   Args: 
     x: 2D numpy array in the format returned by read_array function. 
     config: calibration sample configuration dictionary. 
+    scale: optional vector of scale factors applied before transformation
+           to each dimension of input data (e.g. to rescale multiplicity). 
   """
   transform_sample = [ ]
   for c in config["transform"] : 
-    transform_sample += [ eval("lambda x : (" + c + ")") ]
+    transform_sample += [ eval(f"lambda x : (" + c + ")") ]
 
-  arr = [ t(x[:,i]) for i, t in enumerate(transform_sample) ]
+  if scale : 
+    arr = [ t(x[:,i]*s) for i, (t,s) in enumerate(zip(transform_sample, scale)) ]
+  else : 
+    arr = [ t(x[:,i]) for i, t in enumerate(transform_sample) ]
 
-#  arr = [ 
-#    transform_sample[0](x[:,0]),  # pT
-#    transform_sample[1](x[:,1]),  # eta
-#    transform_sample[2](x[:,2])   # Ntracks
-#  ]
   return np.stack(arr, axis = 1)
 
 def store_to_cache(variable, config, max_files = 0, verbose = False, cachedir = None) : 
