@@ -15,11 +15,11 @@ from itertools import product
 
 common_params = {
     "calib_cache_branches" : ["pt", "eta", "ntr", "sw"],          # Names of variable branches in ROOT tree of the cache file 
-    "calib_cache_dirname" : "calib_cache",                        # Name of the cache ROOT file
     "data_ranges" : [ (2.4, 4.4), (2.0, 5.0), (0.7, 3.1) ],       # Ranges of each variable after transformation
     "labels" : [r"PID", r"$p_T$", r"$\eta$", r"$N_{\rm tr}$"],    # Labels for plots
     "names" : ["pid", "pt", "eta", "ntr"],                        # Short names of each variable for plot file names
     "max_weights" : None, 
+    "smear" : [ None, None, (-0.5, 0.5) ], 
     "transform" : [                                               # Transformation functions for each variable
       "np.log10(x)",   # pT transformation
       "x",             # eta
@@ -28,8 +28,11 @@ common_params = {
     "normalise_bins" : [100, 100, 100],                           # Number of bins for normalisation of each variable
     "normalise_methods" : ["scale", "scale", "flatten"],          # Normalisation method for each variable ("scale", "normalise", "flatten")
     "normalise_ranges" : 2*[ (0., 1.) ] + [ (0., 1.) ],           # Ranges of each variable after normalisation
-    "template_bins" : [100, 100, 50],                             # Number of bins for each variable in the template 
-    "template_sigma" : [2., 4., 4.],                              # Smearing parameter for the template for each variable. 
+    "template_bins" : [70, 70, 20],                               # Number of bins for each variable in the template 
+    "template_sigma" : {
+      "default" : [2., 4., 4.],                              # Smearing parameter for the template for each variable. 
+      "syst1"   : [3., 6., 6.],                              # Smearing parameter for the template for each variable. 
+    }
 }
 
 sample_run2 = {
@@ -38,7 +41,7 @@ sample_run2 = {
     "branches" : [ 
       "probe_Brunel_PT", 
       "probe_Brunel_ETA", 
-      "nTracks_Brunel" if year in ["2017", "2018"] else "nTracks", 
+      "nTracks_Brunel", 
       "probe_sWeight" 
     ], 
     "trees" : ['DSt_PiPTuple/DecayTree', 'DSt_PiMTuple/DecayTree'], 
