@@ -10,14 +10,17 @@
 ###############################################################################
 
 variable = {
-    "branch" : "probe_Brunel_PIDp", 
+    "branch" : "probe_PIDp", 
     "data_range" : (-150., 150.), 
     "transform_forward" : "x", 
     "transform_backward" : "x", 
     "normalise_bins" : 1000, 
     "normalise_method" : "gauss", 
     "normalise_range" : (-2.5, 2.5), 
-    "template_bins" : 200, 
-    "template_sigma" : 2., 
+    "template_bins" : 70, 
+    "template_sigma" : {
+      "default" : 2., 
+      "syst1"  : 3., 
+    }, 
     "resample_bins" : 200, 
 }
