@@ -17,7 +17,10 @@ variable = {
     "normalise_bins" : 1000, 
     "normalise_method" : "gauss", 
     "normalise_range" : (-2.5, 2.5), 
-    "template_bins" : 200, 
-    "template_sigma" : 2., 
+    "template_bins" : 70, 
+    "template_sigma" : {
+      "default" : 2.,
+      "syst1"  : 3.,
+    }, 
     "resample_bins" : 200, 
 }
